pub struct SourceJsonCodec;Trait Implementations
Sourceimpl Debug for SourceJsonCodec
impl Debug for SourceJsonCodec
Sourceimpl Default for SourceJsonCodec
impl Default for SourceJsonCodec
Sourceimpl JsonCapabilityCodec for SourceJsonCodec
impl JsonCapabilityCodec for SourceJsonCodec
Sourcefn capability_id(&self) -> &'static str
fn capability_id(&self) -> &'static str
Stable Capability series identity.
Sourcefn descriptor_version(&self) -> &'static str
fn descriptor_version(&self) -> &'static str
Exact Descriptor version.
Sourcefn descriptor_digest(&self) -> &'static str
fn descriptor_digest(&self) -> &'static str
Canonical digest of the exact generated Descriptor. Read more
Sourcefn request_operations(&self) -> &'static [&'static str]
fn request_operations(&self) -> &'static [&'static str]
Exact request Operation table.
Sourcefn stream_operations(&self) -> &'static [&'static str]
fn stream_operations(&self) -> &'static [&'static str]
Exact bidirectional stream Operation table.
Sourcefn event_operations(&self) -> &'static [&'static str]
fn event_operations(&self) -> &'static [&'static str]
Exact ephemeral Event Operation table.
Sourcefn encode_request(
&self,
operation: &str,
request: &dyn Any,
) -> Result<Value, RuntimeFailure>
fn encode_request( &self, operation: &str, request: &dyn Any, ) -> Result<Value, RuntimeFailure>
Converts one generated request into validated portable JSON.
Sourcefn decode_response(
&self,
operation: &str,
value: Value,
) -> Result<Box<dyn Any>, RuntimeFailure>
fn decode_response( &self, operation: &str, value: Value, ) -> Result<Box<dyn Any>, RuntimeFailure>
Converts portable JSON into the generated response value.
Sourcefn decode_domain_error(
&self,
operation: &str,
value: Value,
) -> Result<Box<dyn Any>, RuntimeFailure>
fn decode_domain_error( &self, operation: &str, value: Value, ) -> Result<Box<dyn Any>, RuntimeFailure>
Converts portable JSON into the generated Domain Error value.
Sourcefn encode_stream_open(
&self,
operation: &str,
_request: &dyn Any,
) -> Result<Value, RuntimeFailure>
fn encode_stream_open( &self, operation: &str, _request: &dyn Any, ) -> Result<Value, RuntimeFailure>
Converts one generated stream-open request into validated portable JSON.
Sourcefn encode_stream_message(
&self,
operation: &str,
_message: &dyn Any,
) -> Result<Value, RuntimeFailure>
fn encode_stream_message( &self, operation: &str, _message: &dyn Any, ) -> Result<Value, RuntimeFailure>
Converts one generated outbound stream message into validated portable JSON.
Sourcefn decode_stream_message(
&self,
operation: &str,
_value: Value,
) -> Result<Box<dyn Any>, RuntimeFailure>
fn decode_stream_message( &self, operation: &str, _value: Value, ) -> Result<Box<dyn Any>, RuntimeFailure>
Converts one portable JSON stream message into its generated value.
Sourcefn decode_stream_domain_error(
&self,
operation: &str,
_value: Value,
) -> Result<Box<dyn Any>, RuntimeFailure>
fn decode_stream_domain_error( &self, operation: &str, _value: Value, ) -> Result<Box<dyn Any>, RuntimeFailure>
Converts one portable JSON stream terminal error into its generated value.
Sourcefn encode_event(
&self,
operation: &str,
_event: &dyn Any,
) -> Result<Value, RuntimeFailure>
fn encode_event( &self, operation: &str, _event: &dyn Any, ) -> Result<Value, RuntimeFailure>
Converts one generated Event value into validated portable JSON.
Sourcefn invoke_host_request(
&self,
dependency: PluginDependencyHandle,
operation: String,
request: Value,
context: InvocationContext,
) -> JsonHostRequestFuture
fn invoke_host_request( &self, dependency: PluginDependencyHandle, operation: String, request: Value, context: InvocationContext, ) -> JsonHostRequestFuture
Invokes one exact Plan-bound host Request dependency from portable JSON.
Sourcefn open_host_stream(
&self,
_dependency: PluginStreamDependencyHandle,
operation: String,
_request: Value,
_context: InvocationContext,
) -> JsonHostStreamOpenFuture
fn open_host_stream( &self, _dependency: PluginStreamDependencyHandle, operation: String, _request: Value, _context: InvocationContext, ) -> JsonHostStreamOpenFuture
Opens one exact Plan-bound host Stream dependency from portable JSON.
Sourcefn publish_host_event(
&self,
_dependency: PluginEventDependencyHandle,
operation: String,
_event: Value,
_context: InvocationContext,
) -> LocalBoxFuture<'static, Result<(), RuntimeFailure>>
fn publish_host_event( &self, _dependency: PluginEventDependencyHandle, operation: String, _event: Value, _context: InvocationContext, ) -> LocalBoxFuture<'static, Result<(), RuntimeFailure>>
Publishes one exact Plan-bound host Event dependency from portable JSON.